@@ -29,16 +29,20 @@ def download_file(url, file_name=None):
     content = b"ERROR"
     if "://" not in raw_target:
         try:
-            cur_path = os.path.join(n_env.server_root, raw_target)
+            cur_path = os.path.join(
+                n_env.path_naas_folder, n_env.server_root, raw_target
+            )
             ff = open(cur_path, "rb")
             content = ff.read()
             ff.close()
         except Exception as e:
-            print("Cannot open local file", e)
+            print(f"Cannot open local file {cur_path}", e)
+            content = b"ERROR: Cannot open local file " + bytes(raw_target, "utf-8")
     else:
         r = requests.get(raw_target)
         content = r.content
-
+    if content.startswith(b"ERROR"):
+        file_name = "dl_error.txt"
     with open(file_name, "wb") as f:
         f.write(content)
         f.close()
