@@ -34,8 +34,29 @@ class CsvFormatter(logging.Formatter):
     def format(self, record):
         print("record", record)
         record.asctime = self.formatTime(record, self.datefmt)
+        try:
+            data = json.loads(record.msg or "{}")
+            if type(data) != dict:
+                data = {"status": data}
+        except ValueError:
+            data = {"status": record.msg}
+        record.id = data.get("id", "")
+        record.type = data.get("type", "")
+        record.filepath = data.get("filepath", "")
+        record.status = data.get("status", "")
+        record.error = data.get("error", "")
+
         self.writer.writerow(
-            [record.asctime, record.levelname, record.name, record.msg]
+            [
+                record.asctime,
+                record.levelname,
+                record.name,
+                record.id,
+                record.type,
+                record.filepath,
+                record.status,
+                record.error,
+            ]
         )
         data = self.output.getvalue()
         self.output.truncate(0)
@@ -47,19 +68,25 @@ class Logger:
     __log = None
     __name = "naas_logger"
     __logs_filename = "logs.csv"
-    __naas_folder = ".naas"
-    __columns = ["asctime", "levelname", "name", "message"]
+    __columns = [
+        "asctime",
+        "levelname",
+        "name",
+        "id",
+        "type",
+        "filepath",
+        "status",
+        "error",
+    ]
 
     def __init__(self, clear=False):
-
-        self.__path_naas_files = os.path.join(n_env.server_root, self.__naas_folder)
         self.__path_logs_file = os.path.join(
-            self.__path_naas_files, self.__logs_filename
+            n_env.path_naas_folder, self.__logs_filename
         )
         if not os.path.exists(self.__path_logs_file):
             try:
                 print("Init Naas folder Logger")
-                os.makedirs(self.__path_naas_files)
+                os.makedirs(n_env.path_naas_folder)
             except OSError as exc:  # Guard against race condition
                 if exc.errno != errno.EEXIST:
                     raise
@@ -76,7 +103,7 @@ class Logger:
         message = ""
         try:
             message = json.dumps(data)
-        except:  # noqa: E722
+        except ValueError:
             message = str(data)
         self.__log.info(message)
 
@@ -84,7 +111,7 @@ class Logger:
         message = ""
         try:
             message = json.dumps(data)
-        except:  # noqa: E722
+        except ValueError:
             message = str(data)
         self.__log.error(message)
 
@@ -108,13 +135,13 @@ class Logger:
         df = None
         try:
             df = pd.read_csv(
-                self.__path_logs_file, sep=";", usecols=self.__columns, index_col=0
+                self.__path_logs_file,
+                sep=";",
+                usecols=self.__columns,
+                index_col=0,
+                error_bad_lines=False,
+                quoting=csv.QUOTE_ALL,
             )
-            df1 = pd.DataFrame(
-                df.pop("message").apply(pd.io.json.loads).values.tolist(),
-                index=df.index,
-            )
-            df = pd.concat([df1, df], axis=1, sort=False)
             if len(filters) > 0:
                 df = df[df.type.isin(filters)]
             if len(sort) > 0:
